@@ -662,7 +662,9 @@ class MessageAttachment(models.Model):
 
     def get_filename(self):
         file_name = self._get_rehydrated_headers().get_filename()
-        if file_name:
+        if isinstance(file_name, six.text_type):
+            return file_name
+        elif file_name:
             return convert_header_to_unicode(file_name)
         else:
             return None
