@@ -1,3 +1,5 @@
+import sys
+
 from .base import EmailTransport
 
 
@@ -7,7 +9,9 @@ class GenericFileMailbox(EmailTransport):
 
     def __init__(self, path):
         super(GenericFileMailbox, self).__init__()
-        self._path = path
+        self._path = path.encode(
+            sys.getfilesystemencoding()
+        )
 
     def get_instance(self):
         return self._variant(self._path)
